from typing import Dict, List

from .prompts import (
    GOOGLE_GET_PRODUCT_PROMPT,
    GOOGLE_GET_PRODUCT_REVIEWS_PROMPT,
    GOOGLE_SEARCH_NEWS_PROMPT,
    GOOGLE_SEARCH_PRODUCTS_PROMPT,
    GOOGLE_SEARCH_WEB_PROMPT,
    LINKEDIN_GET_COMPANY_PROMPT,
    LINKEDIN_GET_JOB_POSTING_PROMPT,
    LINKEDIN_GET_PERSON_PROMPT,
    LINKEDIN_SEARCH_COMPANIES_PROMPT,
    LINKEDIN_SEARCH_JOB_POSTINGS_PROMPT,
    LINKEDIN_SEARCH_PEOPLE_PROMPT,
    NAVIGATOR_SCRAPE_PROMPT,
    SKYSCANNER_SEARCH_FLIGHTS_PROMPT,
    TWITTER_GET_TWEET_PROMPT,
    TWITTER_GET_USER_PROMPT,
    TWITTER_GET_USER_FOLLOWERS_PROMPT,
    TWITTER_GET_USER_FOLLOWINGS_PROMPT,
    TWITTER_GET_USER_TWEETS_PROMPT,
    TWITTER_SEARCH_TWEETS_PROMPT,
    TWITTER_SEARCH_USERS_PROMPT,
    YELP_GET_BUSINESS_PROMPT,
    YELP_GET_BUSINESS_REVIEWS_PROMPT,
    YELP_SEARCH_BUSINESSES_PROMPT,
    ZILLOW_GET_PROPERTY_PROMPT,
    ZILLOW_SEARCH_PROPERTIES_PROMPT,
)

from .schema import (
    GoogleGetProduct,
    GoogleGetProductReviews,
    GoogleSearchNews,
    GoogleSearchProducts,
    GoogleSearchWeb,
    LinkedinGetCompany,
    LinkedinGetJobPosting,
    LinkedinGetPerson,
    LinkedinSearchCompanies,
    LinkedinSearchJobPostings,
    LinkedinSearchPeople,
    NavigatorScrape,
    SkyscannerSearchFlights,
    TwitterGetTweet,
    TwitterGetUserFollowers,
    TwitterGetUserFollowings,
    TwitterGetUser,
    TwitterGetUserTweets,
    TwitterSearchTweets,
    TwitterSearchUsers,
    YelpGetBusiness,
    YelpGetBusinessReviews,
    YelpSearchBusinesses,
    ZillowGetProperty,
    ZillowSearchProperties,
)

tools: List[Dict] = [
    {
        "method": "google_get_product",
        "name": "Google Get Product",
        "description": GOOGLE_GET_PRODUCT_PROMPT,
        "args_schema": GoogleGetProduct,
    },
    {
        "method": "google_get_product_reviews",
        "name": "Google Get Product Reviews",
        "description": GOOGLE_GET_PRODUCT_REVIEWS_PROMPT,
        "args_schema": GoogleGetProductReviews,
    },
    {
        "method": "google_search_news",
        "name": "Google Search News",
        "description": GOOGLE_SEARCH_NEWS_PROMPT,
        "args_schema": GoogleSearchNews,
    },
    {
        "method": "google_search_products",
        "name": "Google Search Products",
        "description": GOOGLE_SEARCH_PRODUCTS_PROMPT,
        "args_schema": GoogleSearchProducts,
    },
    {
        "method": "google_search_web",
        "name": "Google Search Web",
        "description": GOOGLE_SEARCH_WEB_PROMPT,
        "args_schema": GoogleSearchWeb,
    },
    {
        "method": "linkedin_get_company",
        "name": "LinkedIn Get Company",
        "description": LINKEDIN_GET_COMPANY_PROMPT,
        "args_schema": LinkedinGetCompany,
    },
    {
        "method": "linkedin_get_job_posting",
        "name": "LinkedIn Get Job Posting",
        "description": LINKEDIN_GET_JOB_POSTING_PROMPT,
        "args_schema": LinkedinGetJobPosting,
    },
    {
        "method": "linkedin_get_person",
        "name": "LinkedIn Get Person",
        "description": LINKEDIN_GET_PERSON_PROMPT,
        "args_schema": LinkedinGetPerson,
    },
    {
        "method": "linkedin_search_companies",
        "name": "LinkedIn Search Companies",
        "description": LINKEDIN_SEARCH_COMPANIES_PROMPT,
        "args_schema": LinkedinSearchCompanies,
    },
    {
        "method": "linkedin_search_job_postings",
        "name": "LinkedIn Search Job Postings",
        "description": LINKEDIN_SEARCH_JOB_POSTINGS_PROMPT,
        "args_schema": LinkedinSearchJobPostings,
    },
    {
        "method": "linkedin_search_people",
        "name": "LinkedIn Search People",
        "description": LINKEDIN_SEARCH_PEOPLE_PROMPT,
        "args_schema": LinkedinSearchPeople,
    },
    {
        "method": "navigator_scrape",
        "name": "Navigator Scrape",
        "description": NAVIGATOR_SCRAPE_PROMPT,
        "args_schema": NavigatorScrape,
    },
    {
        "method": "skyscanner_search_flights",
        "name": "Skyscanner Search Flights",
        "description": SKYSCANNER_SEARCH_FLIGHTS_PROMPT,
        "args_schema": SkyscannerSearchFlights,
    },
    {
        "method": "twitter_get_tweet",
        "name": "Twitter Get Tweet",
        "description": TWITTER_GET_TWEET_PROMPT,
        "args_schema": TwitterGetTweet,
    },
    {
        "method": "twitter_get_user_followers",
        "name": "Twitter Get User Followers",
        "description": TWITTER_GET_USER_FOLLOWERS_PROMPT,
        "args_schema": TwitterGetUserFollowers,
    },
    {
        "method": "twitter_get_user_followings",
        "name": "Twitter Get User Followings",
        "description": TWITTER_GET_USER_FOLLOWINGS_PROMPT,
        "args_schema": TwitterGetUserFollowings,
    },
    {
        "method": "twitter_get_user",
        "name": "Twitter Get User",
        "description": TWITTER_GET_USER_PROMPT,
        "args_schema": TwitterGetUser,
    },
    {
        "method": "twitter_get_user_tweets",
        "name": "Twitter Get User Tweets",
        "description": TWITTER_GET_USER_TWEETS_PROMPT,
        "args_schema": TwitterGetUserTweets,
    },
    {
        "method": "twitter_search_tweets",
        "name": "Twitter Search Tweets",
        "description": TWITTER_SEARCH_TWEETS_PROMPT,
        "args_schema": TwitterSearchTweets,
    },
    {
        "method": "twitter_search_users",
        "name": "Twitter Search Users",
        "description": TWITTER_SEARCH_USERS_PROMPT,
        "args_schema": TwitterSearchUsers,
    },
    {
        "method": "yelp_get_business",
        "name": "Yelp Get Business",
        "description": YELP_GET_BUSINESS_PROMPT,
        "args_schema": YelpGetBusiness,
    },
    {
        "method": "yelp_get_business_reviews",
        "name": "Yelp Get Business Reviews",
        "description": YELP_GET_BUSINESS_REVIEWS_PROMPT,
        "args_schema": YelpGetBusinessReviews,
    },
    {
        "method": "yelp_search_businesses",
        "name": "Yelp Search Businesses",
        "description": YELP_SEARCH_BUSINESSES_PROMPT,
        "args_schema": YelpSearchBusinesses,
    },
    {
        "method": "zillow_get_property",
        "name": "Zillow Get Property",
        "description": ZILLOW_GET_PROPERTY_PROMPT,
        "args_schema": ZillowGetProperty,
    },
    {
        "method": "zillow_search_properties",
        "name": "Zillow Search Properties",
        "description": ZILLOW_SEARCH_PROPERTIES_PROMPT,
        "args_schema": ZillowSearchProperties,
    }
]
